@@ -15,9 +15,12 @@ def get_articles():
 	
 	css_path1 = ".row.sidebar-item.js_sidebar-element .column .headline a"
 	css_path2 = "article.post.hentry.js_post-item header .headline a"
+	summary_path = ".columns p.first-text"
 	
-	posts += parser.get_articles(g, css_path1, css_path1, "gizmodo")
-	posts += parser.get_articles(g, css_path2, css_path2, "gizmodo")
+	posts += parser.get_articles(g, css_path1, css_path1,
+		"gizmodo", "gizmodo.com", summary_path)
+	posts += parser.get_articles(g, css_path2, css_path2,
+		"gizmodo", "gizmodo.com", summary_path)
 	
 	links = []
 	
